@@ -1,11 +1,9 @@
 /*
-@(#)File:            $RCSfile: decsci.h,v $
-@(#)Version:         $Revision: 1.6 $
-@(#)Last changed:    $Date: 1999/05/16 04:53:33 $
 @(#)Purpose:         JLSS Functions to manipulate DECIMAL values
 @(#)Author:          J Leffler
-@(#)Copyright:       (C) JLSS 1996-99
-@(#)Product:         Informix Database Driver for Perl Version 0.97005 (2000-02-10)
+@(#)Copyright:       1996-99 Jonathan Leffler (JLSS)
+@(#)Copyright:       2002    IBM
+@(#)Product:         IBM Informix Database Driver for Perl Version 2003.03.0303 (2003-03-03)
 */
 
 /*TABSTOP=4*/
@@ -15,7 +13,7 @@
 
 #ifdef MAIN_PROGRAM
 #ifndef lint
-static const char decsci_h[] = "@(#)$Id: decsci.h version /main/6 1999-05-16 04:53:33 $";
+static const char decsci_h[] = "@(#)$Id: decsci.h,v 100.2 2002/12/06 22:18:25 jleffler Exp $";
 #endif	/* lint */
 #endif	/* MAIN_PROGRAM */
 
@@ -32,7 +30,7 @@ extern char *decfix(const dec_t *d, int ndigit, int plus);
 extern char *decsci(const dec_t *d, int ndigit, int plus);
 extern char *deceng(const dec_t *d, int ndigit, int plus, int cw);
 
-extern int decfmt(const dec_t *d, int sqllen, int fmtcode, char *buffer, size_t buflen); 
+extern int decfmt(const dec_t *d, int sqllen, int fmtcode, char *buffer, size_t buflen);
 extern int decchk(dec_t *d, int sqllen);
 extern int decset(dec_t *d, int sqllen);
 
