@@ -1,11 +1,9 @@
 /*
-@(#)File:            $RCSfile: esql_ius.h,v $
-@(#)Version:         $Revision: 3.1 $
-@(#)Last changed:    $Date: 1998/11/05 21:03:26 $
 @(#)Purpose:         Supply key macros from IUS version of sqltypes.h
 @(#)Author:          J Leffler
-@(#)Copyright:       (C) JLSS 1998
-@(#)Product:         Informix Database Driver for Perl Version 0.97005 (2000-02-10)
+@(#)Copyright:       1998 Jonathan Leffler (JLSS)
+@(#)Copyright:       2002 IBM
+@(#)Product:         IBM Informix Database Driver for Perl Version 2003.03.0303 (2003-03-03)
 */
 
 /*TABSTOP=4*/
@@ -15,7 +13,7 @@
 
 #ifdef MAIN_PROGRAM
 #ifndef lint
-static const char esql_ius_h[] = "@(#)$Id: esql_ius.h version /main/1 1998-11-05 21:03:26 $";
+static const char esql_ius_h[] = "@(#)$Id: esql_ius.h,v 100.2 2002/12/06 22:18:26 jleffler Exp $";
 #endif	/* lint */
 #endif	/* MAIN_PROGRAM */
 
@@ -24,7 +22,7 @@ static const char esql_ius_h[] = "@(#)$Id: esql_ius.h version /main/1 1998-11-05
 #define CINT8TYPE	117
 #endif
 #ifndef CCOLLTYPE
-#define CCOLLTYPE       118   
+#define CCOLLTYPE       118
 #endif
 #ifndef CLVCHARTYPE
 #define CLVCHARTYPE     119
