@@ -1,11 +1,9 @@
 /*
-@(#)File:            $RCSfile: ixblob.h,v $
-@(#)Version:         $Revision: 50.3 $
-@(#)Last changed:    $Date: 1998/04/09 21:48:10 $
 @(#)Purpose:         ESQL/C Utility Functions for DBD::Informix
 @(#)Author:          J Leffler
-@(#)Copyright:       (C) Jonathan Leffler 1997-98
-@(#)Product:         Informix Database Driver for Perl Version 0.97005 (2000-02-10)
+@(#)Copyright:       1997-98 Jonathan Leffler
+@(#)Copyright:       2002    IBM
+@(#)Product:         IBM Informix Database Driver for Perl Version 2003.03.0303 (2003-03-03)
 */
 
 /*TABSTOP=4*/
@@ -15,7 +13,7 @@
 
 #ifdef MAIN_PROGRAM
 #ifndef lint
-static const char ixblob_h[] = "@(#)$Id: ixblob.h version /main/4 1998-04-09 21:48:10 $";
+static const char ixblob_h[] = "@(#)$Id: ixblob.h,v 100.1 2002/02/08 22:49:28 jleffler Exp $";
 #endif	/* lint */
 #endif	/* MAIN_PROGRAM */
 
