@@ -1,11 +1,9 @@
 /*
-@(#)File:            $RCSfile: link.c,v $
-@(#)Version:         $Revision: 61.1 $
-@(#)Last changed:    $Date: 1998/10/29 19:30:58 $
 @(#)Purpose:         Specialized doubly-linked list management routines
 @(#)Author:          J Leffler
-@(#)Copyright:       (C) Jonathan Leffler 1996-98
-@(#)Product:         Informix Database Driver for Perl Version 0.97005 (2000-02-10)
+@(#)Copyright:       1996-98 Jonathan Leffler
+@(#)Copyright:       2002-03 IBM
+@(#)Product:         IBM Informix Database Driver for Perl Version 2003.03.0303 (2003-03-03)
 */
 
 /*TABSTOP=4*/
@@ -24,7 +22,7 @@
 #endif /* DBD_IX_DEBUG_LINK */
 
 #ifndef lint
-static const char rcs[] = "@(#)$Id: link.c version /main/9 1998-10-29 19:30:58 $";
+static const char rcs[] = "@(#)$Id: link.c,v 2003.2 2003/02/28 21:13:14 jleffler Exp $";
 #endif
 
 #ifdef DBD_IX_DEBUG_LINK
@@ -78,12 +76,12 @@ void dbd_ix_link_delete(Link *link_d, void (*function)(void *))
 void dbd_ix_link_delchain(Link *head, void (*function)(void *))
 {
 	/* Delete all links */
-	dbd_ix_debug(1, "-->> %s::dbd_ix_link_delchain()\n", "DBD::Informix");
+	dbd_ix_debug(1, "-->> %s::dbd_ix_link_delchain()\n", dbd_ix_module());
 	PRINT_LIST("dbd_ix_link_delchain:before", head);
 	while (head->next->data != 0)
 		dbd_ix_link_delete(head->next, function);
 	PRINT_LIST("dbd_ix_link_delchain:after", head);
-	dbd_ix_debug(1, "<<-- %s::dbd_ix_link_delchain()\n", "DBD::Informix");
+	dbd_ix_debug(1, "<<-- %s::dbd_ix_link_delchain()\n", dbd_ix_module());
 }
 
 /* Add the link (link_n) after a pre-existing link in a list (link_1) */
