@@ -1,11 +1,9 @@
 /*
-@(#)File:            $RCSfile: odbctype.h,v $
-@(#)Version:         $Revision: 54.3 $
-@(#)Last changed:    $Date: 1997/04/01 16:22:30 $
 @(#)Purpose:         Surrogate ODBC header for DBD::Informix
 @(#)Author:          J Leffler
-@(#)Copyright:       (C) JLSS 1997
-@(#)Product:         Informix Database Driver for Perl Version 0.97005 (2000-02-10)
+@(#)Copyright:       1997 Jonathan Leffler (JLSS)
+@(#)Copyright:       2002 IBM
+@(#)Product:         IBM Informix Database Driver for Perl Version 2003.03.0303 (2003-03-03)
 */
 
 /*TABSTOP=4*/
@@ -15,7 +13,7 @@
 
 #ifdef MAIN_PROGRAM
 #ifndef lint
-static const char odbctype_h[] = "@(#)$Id: odbctype.h version /main/4 1997-04-01 16:22:30 $";
+static const char odbctype_h[] = "@(#)$Id: odbctype.h,v 100.1 2002/02/08 22:49:36 jleffler Exp $";
 #endif	/* lint */
 #endif	/* MAIN_PROGRAM */
 
