@@ -1,11 +1,9 @@
 /*
-@(#)File:            $RCSfile: sqltoken.c,v $
-@(#)Version:         $Revision: 1.9 $
-@(#)Last changed:    $Date: 1999/03/12 18:53:55 $
 @(#)Purpose:         Identify SQL token in string
 @(#)Author:          J Leffler
-@(#)Copyright:       (C) JLSS 1998
-@(#)Product:         Informix Database Driver for Perl Version 0.97005 (2000-02-10)
+@(#)Copyright:       1998-99 Jonathan Leffler (JLSS)
+@(#)Copyright:       2002    IBM
+@(#)Product:         IBM Informix Database Driver for Perl Version 2003.03.0303 (2003-03-03)
 */
 
 /*TABSTOP=4*/
@@ -20,7 +18,7 @@
 #define RCURLY '}'
 
 #ifndef lint
-static const char rcs[] = "@(#)$Id: sqltoken.c version /main/9 1999-03-12 18:53:55 $";
+static const char rcs[] = "@(#)$Id: sqltoken.c,v 100.2 2002/12/06 22:18:23 jleffler Exp $";
 #endif
 
 /*
@@ -29,7 +27,7 @@ static const char rcs[] = "@(#)$Id: sqltoken.c version /main/9 1999-03-12 18:53:
 ** Returns pointer to start of next SQL token (keyword, string,
 ** punctuation) in given string, or pointer to null at end of string if
 ** there is none.  The end of the token is in the end parameter.
-*/ 
+*/
 char *sqltoken(char *input, char **end)
 {
 	char *token;
